import { IState, IJwtOptions } from './models';
declare global {
    interface Window {
        Raven: any;
        BroadcastChannel?: any;
    }
}
/**
 * Kicks off all the session-related things again.
 *
 * @memberof module:jwt
 * @private
 */
declare function reinit(): void;
/**
 * Kicks off all the session-related things.
 * https://www.keycloak.org/docs/latest/securing_apps/index.html#init-options
 * @memberof module:jwt
 * @private
 */
declare function init(jwtOptions: IJwtOptions): Promise<void>;
/**
 * Register a function to be called when jwt.js has initialized.  Runs
 * immediately if already initialized.  When called, the function will be
 * passed a reference to the jwt.js API.
 *
 * @memberof module:jwt
 */
declare function onInit(func: Function): void;
/**
 * Register a function to be called when jwt.js has initialized and
 * the first token update has successful run
 * @memberof module:jwt
 */
declare function onInitialUpdateToken(func: Function): void;
/**
 * Register a function to be called when the tokens mismatch.  This is a hard
 * error caused when mixing sso envs/tokens and requires a logout/log back in
 * @memberof module:jwt
 */
declare function onTokenMismatch(func: Function): void;
/**
 * Register a function to be called when the tokens mismatch.  This is a hard
 * error caused when mixing sso envs/tokens and requires a logout/log back in
 * @memberof module:jwt
 */
declare function onJwtTokenUpdateFailed(func: Function): void;
/**
 * Enable debug logging
 * @memberof module:jwt
 */
declare function enableDebugLogging(): Promise<void>;
/**
 * Disable debug logging
 * @memberof module:jwt
 */
declare function disableDebugLogging(): void;
declare function onAuthError(): void;
/**
 * Register a function to be called when keycloak has failed to refresh the session.  Runs
 * immediately if already initialized.  When called, the function will be
 * passed a reference to the jwt.js API.
 *
 * @memberof module:jwt
 */
declare function onAuthRefreshError(func: Function): void;
/**
 * Register a function to be called when keycloak has successfully to refresh the session.
 *
 * @memberof module:jwt
 */
declare function onAuthRefreshSuccess(func: Function): void;
/**
 * Register a function to be called when keycloak has logged out.
 *
 * @memberof module:jwt
 */
declare function onAuthLogout(func: Function): void;
/**
 * Register a function to be called when keycloak init fails.
 *
 * @memberof module:jwt
 */
declare function onInitError(func: Function): void;
/**
 * Register a function to be called when keycloak as expired the token.  Runs
 * immediately if already initialized.  When called, the function will be
 * passed a reference to the jwt.js API.
 *
 * @memberof module:jwt
 */
declare function onTokenExpired(func: Function): void;
/**
 * When the token expires
 * @memberof module:jwt
 * @private
 */
declare function expiresIn(): number;
/**
  * Get the count of the $key.
  * @return {Number} Get the count of the $key.
  * @memberof module:jwt
  */
declare function getCountForKey(key: string): Promise<number>;
/**
 * Return whether or not the consecutive failure count has been exceeded.
 * @memberof module:jwt
 * @return {Boolean} has the consecutive failure count been exceeded
 */
declare function failCountPassed(key: string, threshold: number): Promise<boolean>;
declare const Jwt: {
    login: () => any;
    logout: () => any;
    register: () => any;
    hasRole: () => any;
    isInternal: () => any;
    isAuthenticated: () => any;
    getRegisterUrl: () => any;
    getLoginUrl: () => any;
    getLogoutUrl: () => any;
    getAccountUrl: () => any;
    getToken: () => any;
    getStoredTokenValue: () => any;
    getEncodedToken: () => any;
    getUserInfo: () => any;
    updateToken: () => any;
    cancelRefreshLoop: () => any;
    startRefreshLoop: () => any;
    isTokenExpired: () => any;
    onInit: typeof onInit;
    onInitError: typeof onInitError;
    onAuthRefreshError: typeof onAuthRefreshError;
    onAuthRefreshSuccess: typeof onAuthRefreshSuccess;
    onAuthLogout: typeof onAuthLogout;
    onTokenExpired: typeof onTokenExpired;
    onInitialUpdateToken: typeof onInitialUpdateToken;
    onTokenMismatch: typeof onTokenMismatch;
    onJwtTokenUpdateFailed: typeof onJwtTokenUpdateFailed;
    onAuthError: typeof onAuthError;
    enableDebugLogging: typeof enableDebugLogging;
    disableDebugLogging: typeof disableDebugLogging;
    init: typeof init;
    reinit: typeof reinit;
    _state: IState;
    getCountForKey: typeof getCountForKey;
    failCountPassed: typeof failCountPassed;
    expiresIn: typeof expiresIn;
};
export default Jwt;
