import * as Keycloak from 'keycloak-js';
import { SsoEnv } from './ssoEnvEnum';
export interface IKeycloakOptions extends Keycloak.KeycloakConfig {
    credentials?: any;
    internalAuth?: boolean;
}
export interface IKeycloakInitOptions extends Keycloak.KeycloakInitOptions {
    responseMode?: "query" | "fragment";
    flow: "standard" | "implicit" | "hybrid";
    refreshToken: string;
    adapter?: any;
    checkLoginIframe?: any;
    checkLoginIframeInterval?: number;
}
export interface IJwtOptions {
    keycloakOptions: Partial<IKeycloakOptions>;
    keycloakInitOptions?: Partial<IKeycloakInitOptions>;
    disablePolling?: boolean;
    reLoginIframeEnabled?: boolean;
    reLoginIframe?: any;
    disableBroadcastMessage?: boolean;
    generateJwtTokenCookie?: boolean;
    ssoEnv?: SsoEnv;
}
export interface ILoginOptions {
    redirectUri?: string;
    skipRedirect?: boolean;
}
export interface IJwtUser {
    user_id: string;
    id: string;
    username: string;
    account_id: string;
    account_number: string;
    email: string;
    firstName: string;
    lastName: string;
    lang: string;
    region: string;
    login: string;
    internal: boolean;
}
export interface IToken {
    REDHAT_LOGIN: string;
    RHAT_LOGIN: string;
    account_id: string;
    account_number: string;
    acr: string;
    'allowed-origins': string[];
    aud: string;
    auth_time: number;
    azp: string;
    client_session: string;
    country: string;
    email: string;
    employeeId: string;
    exp: number;
    firstName: string;
    iat: number;
    iss: string;
    jti: string;
    lang: string;
    lastName: string;
    nbf: number;
    nonce: string;
    organization_id: string;
    portal_id: string;
    realm_access: {
        roles: string[];
    };
    region: string;
    resource_access: {
        'realm-management': {
            'roles': string[];
        };
    };
    session_state: string;
    siteID: string;
    siteId: string;
    sub: string;
    typ: string;
    user_id: string;
    username: string;
}
export interface IKeycloakInstance extends Keycloak.KeycloakInstance {
    /**
     * Added by jwt-redhat to make sure we remove old Iframe from dom on reinit
     * Please keep it while updating jwt version to make sure reinit works smoothly
     * This can be removed if keycloak starts providing a reliable reinit functionality.
     * @param none
     * @returns undefined.
     */
    removeIframeFromDom(): void;
}
export interface IState {
    initialized: boolean;
    keycloak: IKeycloakInstance;
}
export interface ITokenResponse {
    access_token: string;
    expires_in: number;
    id_token: string;
    'not-before-policy': number;
    refresh_expires_in: number;
    refresh_token: string;
    session_state: string;
    token_type: string;
}
export interface IKeycloakCallback {
    state: string;
    nonce: string;
    redirectUri: string;
    expires: number;
}
export interface ITokenUpdateFailure {
    status: number;
    statusText: string;
    url: string;
    date: string;
    minValidity: number;
    tokenExpired: boolean;
    expiresIn: number;
}
export interface IRealmAccess {
    roles: string[];
}
export interface IAccount {
    roles: string[];
}
export interface IResourceAccess {
    account: IAccount;
}
export interface IInternalToken {
    jti: string;
    exp: number;
    nbf: number;
    iat: number;
    iss: string;
    aud: string;
    sub: string;
    typ: string;
    azp: string;
    nonce: string;
    auth_time: number;
    session_state: string;
    acr: string;
    client_session?: string;
    'allowed-origins': string[];
    realm_access: IRealmAccess;
    resource_access: IResourceAccess;
    employeeType?: string;
    rhatGeo?: string;
    rhatJobTitle?: string;
    preferredTimeZone?: string;
    rhatUUID?: string;
    name: string;
    preferred_username: string;
    given_name: string;
    family_name: string;
    email: string;
}
export interface IBroadcastChannelPayload {
    type: string;
    clientId: string;
    authenticated: boolean;
}
export interface IBroadcastChannelPayloadEvent {
    data: IBroadcastChannelPayload;
    [key: string]: any;
}
